@@ -33,7 +33,6 @@
 #include "helpviewer.h"
 #include "openpagesmanager.h"
 #include "tracer.h"
-#include "../shared/collectionconfiguration.h"
 
 #include <QtCore/QRegExp>
 #include <QtCore/QTimer>
@@ -55,7 +54,7 @@
 QT_BEGIN_NAMESPACE
 
 namespace {
-    CentralWidget *staticCentralWidget = 0;
+    CentralWidget *staticCentralWidget = nullptr;
 }
 
 // -- TabBar
@@ -184,7 +183,7 @@ void TabBar::slotCustomContextMenuRequested(const QPoint &pos)
 CentralWidget::CentralWidget(QWidget *parent)
     : QWidget(parent)
 #ifndef QT_NO_PRINTER
-    , m_printer(0)
+    , m_printer(nullptr)
 #endif
     , m_findWidget(new FindWidget(this))
     , m_stackedWidget(new QStackedWidget(this))
@@ -194,7 +193,7 @@ CentralWidget::CentralWidget(QWidget *parent)
     staticCentralWidget = this;
     QVBoxLayout *vboxLayout = new QVBoxLayout(this);
 
-    vboxLayout->setMargin(0);
+    vboxLayout->setContentsMargins(QMargins());
     vboxLayout->setSpacing(0);
     vboxLayout->addWidget(m_tabBar);
     m_tabBar->setVisible(HelpEngineWrapper::instance().showTabs());
@@ -462,7 +461,7 @@ void CentralWidget::find(const QString &ttf, bool forward, bool incremental)
     TRACE_OBJ
     bool found = false;
     if (HelpViewer *viewer = currentHelpViewer()) {
-        HelpViewer::FindFlags flags = 0;
+        HelpViewer::FindFlags flags;
         if (!forward)
             flags |= HelpViewer::FindBackward;
         if (m_findWidget->caseSensitive())
@@ -542,11 +541,14 @@ void CentralWidget::highlightSearchTerms()
     TRACE_OBJ
     QHelpSearchEngine *searchEngine =
         HelpEngineWrapper::instance().searchEngine();
-    const QStringList &words = searchEngine->searchInput().split(QRegExp("\\W+"), QString::SkipEmptyParts);
-
+    const QString searchInput = searchEngine->searchInput();
+    const bool wholePhrase = searchInput.startsWith(QLatin1Char('"')) &&
+                             searchInput.endsWith(QLatin1Char('"'));
+    const QStringList &words = wholePhrase ? QStringList(searchInput.mid(1, searchInput.length() - 2)) :
+                                searchInput.split(QRegExp("\\W+"), QString::SkipEmptyParts);
     HelpViewer *viewer = currentHelpViewer();
     for (const QString &word : words)
-        viewer->findText(word, 0, false, true);
+        viewer->findText(word, nullptr, false, true);
     disconnect(viewer, &HelpViewer::loadFinished,
                this, &CentralWidget::highlightSearchTerms);
 }
